# API Reference

This page provides the technical documentation for all public functions in `indium`.

::: indium.invisibles
    options:
      show_root_heading: true

::: indium.spoofing
    options:
      show_root_heading: true

::: indium.segments
    options:
      show_root_heading: true
